/*! This file is auto-generated */
/* Include margin and padding in the width calculation of input and textarea. */
input,
select,
textarea,
button {
	box-sizing: border-box;
	font-family: inherit;
	font-size: inherit;
	font-weight: inherit;
}

textarea,
input {
	font-size: 14px;
}

textarea {
	overflow: auto;
	padding: 8px 12px;
	/* inherits font size 14px */
	line-height: 1.42857143; /* 20px */
	resize: vertical;
}

input,
select {
	margin: 0 1px;
}

textarea.code {
	padding: 8px 12px;
}

input[type="text"],
input[type="password"],
input[type="color"],
input[type="date"],
input[type="datetime"],
input[type="datetime-local"],
input[type="email"],
input[type="month"],
input[type="number"],
input[type="search"],
input[type="tel"],
input[type="time"],
input[type="url"],
input[type="week"],
select,
textarea {
	box-shadow: 0 0 0 transparent;
	border-radius: 2px;
	border: 1px solid #949494;
	background-color: #fff;
	color: #1e1e1e;
}

input[type="text"],
input[type="password"],
input[type="date"],
input[type="datetime"],
input[type="datetime-local"],
input[type="email"],
input[type="month"],
input[type="number"],
input[type="search"],
input[type="tel"],
input[type="time"],
input[type="url"],
input[type="week"] {
	padding: 0 12px;
	/* inherits font size 14px */
	min-height: 40px;
}

select {
	padding: 0 12px 0 24px;
	/* inherits font size 14px */
	line-height: 2.71428571; /* 38px for 40px min-height */
	min-height: 40px;
}

::-webkit-datetime-edit {
	/* inherits font size 14px */
	line-height: 1.85714286; /* 26px */
}

input[type="text"]:focus,
input[type="password"]:focus,
input[type="color"]:focus,
input[type="date"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="email"]:focus,
input[type="month"]:focus,
input[type="number"]:focus,
input[type="search"]:focus,
input[type="tel"]:focus,
input[type="time"]:focus,
input[type="url"]:focus,
input[type="week"]:focus,
select:focus,
textarea:focus {
	border-color: var(--wp-admin-theme-color);
	box-shadow: 0 0 0 var(--wp-admin-border-width-focus, 1.5px) var(--wp-admin-theme-color);
	/* Only visible in Windows High Contrast mode */
	outline: 2px solid transparent;
}

/* Checkbox and radio use outset focus style */
input[type="checkbox"]:focus,
input[type="radio"]:focus {
	border-color: #1e1e1e;
	box-shadow: 0 0 0 2px #fff, 0 0 0 4px var(--wp-admin-theme-color);
	/* Only visible in Windows High Contrast mode */
	outline: 2px solid transparent;
}

/* rtl:ignore */
.ltr,
input[type="password"],
input[type="email"],
input[type="url"] {
	direction: ltr;
}

input[type="checkbox"],
input[type="radio"] {
	border: 1px solid #1e1e1e;
	border-radius: 2px;
	background: #fff;
	color: #1e1e1e;
	clear: none;
	cursor: pointer;
	display: inline-block;
	line-height: 0;
	height: 1rem;
	margin: -0.25rem 0 0 0.25rem;
	outline: 0;
	padding: 0 !important;
	text-align: center;
	vertical-align: middle;
	width: 1rem;
	min-width: 1rem;
	-webkit-appearance: none;
	box-shadow: none;
	transition: .05s border-color ease-in-out;
}

input[type="radio"]:checked + label:before {
	color: #949494;
}

.wp-core-ui input[type="reset"]:hover,
.wp-core-ui input[type="reset"]:active {
	color: #135e96;
}

td > input[type="checkbox"],
.wp-admin p input[type="checkbox"],
.wp-admin p input[type="radio"] {
	margin-top: 0;
}

.wp-admin p label input[type="checkbox"] {
	margin-top: -4px;
}

.wp-admin p label input[type="radio"] {
	margin-top: -2px;
}

input[type="radio"] {
	display: inline-flex;
	border-radius: 50%;
	margin-left: 0.25rem;
	align-items: center;
	justify-content: center;
}

input[type="checkbox"]:checked::before,
input[type="radio"]:checked::before {
	float: right;
	display: inline-block;
	vertical-align: middle;
	width: 1rem;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

input[type="checkbox"]:checked::before {
	/* Use the "Yes" SVG Dashicon */
	content: url("data:image/svg+xml;utf8,%3Csvg%20xmlns%3D%27http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%27%20viewBox%3D%270%200%2020%2020%27%3E%3Cpath%20d%3D%27M14.83%204.89l1.34.94-5.81%208.38H9.02L5.78%209.67l1.34-1.25%202.57%202.4z%27%20fill%3D%27%23ffffff%27%2F%3E%3C%2Fsvg%3E");
	content: url("data:image/svg+xml;utf8,%3Csvg%20xmlns%3D%27http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%27%20viewBox%3D%270%200%2020%2020%27%3E%3Cpath%20d%3D%27M14.83%204.89l1.34.94-5.81%208.38H9.02L5.78%209.67l1.34-1.25%202.57%202.4z%27%20fill%3D%27%23ffffff%27%2F%3E%3C%2Fsvg%3E") / '';
	margin: -0.1875rem -0.25rem 0 0;
	height: 1.3125rem;
	width: 1.3125rem;
}

input[type="checkbox"]:checked {
	background: var(--wp-admin-theme-color);
	border-color: var(--wp-admin-theme-color);
}

input[type="radio"]:checked {
	background: var(--wp-admin-theme-color);
	border-color: var(--wp-admin-theme-color);
}

input[type="radio"]:checked::before {
	content: "";
	border-radius: 50%;
	width: 0.5rem; /* 8px */
	height: 0.5rem; /* 8px */
	margin: auto;
	background-color: #fff;
	/* Only visible in Windows High Contrast mode */
	outline: 4px solid transparent;
}

@-moz-document url-prefix() {
	input[type="checkbox"],
	input[type="radio"],
	.form-table input.tog {
		margin-bottom: -1px;
	}
}

/* Search */
input[type="search"] {
	-webkit-appearance: textfield;
}

input[type="search"]::-webkit-search-decoration {
	display: none;
}

input[type="search"]::-webkit-search-cancel-button {
	cursor: pointer;
}

.wp-admin input[type="file"] {
	padding: 3px 0;
	cursor: pointer;
}

input.readonly,
input[readonly],
textarea.readonly,
textarea[readonly] {
	background-color: #f0f0f0;
}

::-webkit-input-placeholder {
	color: #757575;
}

::-moz-placeholder {
	color: #757575;
}

.form-invalid .form-required,
.form-invalid .form-required:focus,
.form-invalid.form-required input,
.form-invalid.form-required input:focus,
.form-invalid.form-required select,
.form-invalid.form-required select:focus {
	border-color: #d63638 !important;
	box-shadow: 0 0 2px rgba(214, 54, 56, 0.8);
}

.form-table .form-required.form-invalid td:after {
	content: "\f534";
	content: "\f534" / '';
	font: normal 20px/1 dashicons;
	color: #d63638;
	margin-right: -25px;
	vertical-align: middle;
}

/* Adjust error indicator for password layout */
.form-table .form-required.user-pass1-wrap.form-invalid td:after {
	content: "";
}

.form-table .form-required.user-pass1-wrap.form-invalid .password-input-wrapper:after {
	content: "\f534";
	content: "\f534" / '';
	font: normal 20px/1 dashicons;
	color: #d63638;
	margin: 0 -29px 0 6px;
	vertical-align: middle;
}

.form-input-tip {
	color: #646970;
}

input:disabled,
input.disabled,
select:disabled,
select.disabled,
textarea:disabled,
textarea.disabled {
	background: #f0f0f0;
	border-color: #cccccc;
	box-shadow: none;
	color: #949494;
}

input[type="file"]:disabled,
input[type="file"].disabled,
input[type="file"][aria-disabled="true"],
input[type="range"]:disabled,
input[type="range"].disabled,
input[type="range"][aria-disabled="true"] {
	background: none;
	box-shadow: none;
	cursor: default;
}

input[type="checkbox"]:disabled,
input[type="checkbox"].disabled,
input[type="checkbox"][aria-disabled="true"],
input[type="radio"]:disabled,
input[type="radio"].disabled,
input[type="radio"][aria-disabled="true"],
input[type="checkbox"]:disabled:checked:before,
input[type="checkbox"].disabled:checked:before,
input[type="radio"]:disabled:checked:before,
input[type="radio"].disabled:checked:before {
	opacity: 0.7;
	cursor: default;
}

/*------------------------------------------------------------------------------
  2.0 - Forms
------------------------------------------------------------------------------*/

/* Select styles are based on the default button in buttons.css */
.wp-core-ui select {
	font-size: 14px;
	line-height: 2.71428571; /* 38px for 40px min-height */
	color: #1e1e1e;
	border-color: #949494;
	box-shadow: none;
	border-radius: 2px;
	padding: 0 12px 0 24px;
	min-height: 40px;
	max-width: 25rem;
	-webkit-appearance: none;
	/* The SVG is arrow-down-alt2 from Dashicons. */
	background: #fff url('data:image/svg+xml;charset=US-ASCII,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22M5%206l5%205%205-5%202%201-7%207-7-7%202-1z%22%20fill%3D%22%231e1e1e%22%2F%3E%3C%2Fsvg%3E') no-repeat left 8px top 55%;
	background-size: 16px 16px;
	cursor: pointer;
	vertical-align: middle;
}

.wp-core-ui select:hover {
	color: #1e1e1e;
	border-color: #1e1e1e;
}

.wp-core-ui select:focus {
	border-color: var(--wp-admin-theme-color);
	color: #1e1e1e;
	box-shadow: 0 0 0 var(--wp-admin-border-width-focus, 1.5px) var(--wp-admin-theme-color);
}

.wp-core-ui select:active {
	border-color: #949494;
	box-shadow: none;
}

.wp-core-ui select.disabled,
.wp-core-ui select:disabled {
	color: #a7aaad;
	border-color: #dcdcde;
	background-color: #f6f7f7;
	/* The SVG is arrow-down-alt2 from Dashicons. */
	background-image: url('data:image/svg+xml;charset=US-ASCII,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22M5%206l5%205%205-5%202%201-7%207-7-7%202-1z%22%20fill%3D%22%23a0a5aa%22%2F%3E%3C%2Fsvg%3E');
	box-shadow: none;
	text-shadow: 0 1px 0 #fff;
	cursor: default;
	transform: none;
}

.wp-core-ui select[aria-disabled="true"] {
	cursor: default;
}

/* Reset Firefox inner outline that appears on :focus. */
/* This ruleset overrides the color change on :focus thus needs to be after select:focus. */
.wp-core-ui select:-moz-focusring {
	color: transparent;
	text-shadow: 0 0 0 #0a4b78;
}

/* Remove background focus style from IE11 while keeping focus style available on option elements. */
.wp-core-ui select::-ms-value {
	background: transparent;
	color: #50575e;
}

.wp-core-ui select:hover::-ms-value {
	color: #1e1e1e;
}

.wp-core-ui select:focus::-ms-value {
	color: #0a4b78;
}

.wp-core-ui select.disabled::-ms-value,
.wp-core-ui select:disabled::-ms-value {
	color: #a7aaad;
}

/* Hide the native down arrow for select element on IE. */
.wp-core-ui select::-ms-expand {
	display: none;
}

.wp-admin .button-cancel {
	display: inline-block;
	min-height: 28px;
	padding: 0 5px;
	line-height: 2;
}

.meta-box-sortables select {
	max-width: 100%;
}

.meta-box-sortables input {
	vertical-align: middle;
}

.misc-pub-post-status select {
	margin-top: 0;
}

.wp-core-ui select[multiple] {
	height: auto;
	padding-left: 8px;
	background: #fff;
}

.submit {
	padding: 1.5em 0;
	margin: 5px 0;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
	border: none;
}

form p.submit a.cancel:hover {
	text-decoration: none;
}

p.submit {
	text-align: right;
	max-width: 100%;
	margin-top: 20px;
	padding-top: 10px;
}

.textright p.submit {
	border: none;
	text-align: left;
}

table.form-table + p.submit,
table.form-table + input + p.submit,
table.form-table + input + input + p.submit {
	border-top: none;
	padding-top: 0;
}

#minor-publishing-actions input,
#major-publishing-actions input,
#minor-publishing-actions .preview {
	text-align: center;
}

textarea.all-options,
input.all-options {
	width: 250px;
}

input.large-text,
textarea.large-text {
	width: 99%;
}

.regular-text {
	width: 25em;
}

input.small-text {
	width: 50px;
	padding: 0 8px;
}

label input.small-text {
	margin-top: -4px;
}

input[type="number"].small-text {
	width: 65px;
	padding-left: 4px;
}

input.tiny-text {
	width: 35px;
}

input[type="number"].tiny-text {
	width: 45px;
	padding-left: 0;
}

#doaction,
#doaction2,
#post-query-submit {
	margin: 0 0 0 8px;
	min-height: 32px;
	line-height: 2.30769231; /* 30px for 32px height with 13px font */
	padding: 0 12px;
}

/* @since 5.7.0 secondary bulk action controls require JS. */
.no-js label[for="bulk-action-selector-bottom"],
.no-js select#bulk-action-selector-bottom,
.no-js input#doaction2,
.no-js label[for="new_role2"],
.no-js select#new_role2,
.no-js input#changeit2 {
	display: none;
}

.wp-core-ui .tablenav input[type="text"],
.wp-core-ui .tablenav input[type="password"],
.wp-core-ui .tablenav input[type="date"],
.wp-core-ui .tablenav input[type="datetime"],
.wp-core-ui .tablenav input[type="datetime-local"],
.wp-core-ui .tablenav input[type="email"],
.wp-core-ui .tablenav input[type="month"],
.wp-core-ui .tablenav input[type="number"],
.wp-core-ui .tablenav input[type="search"],
.wp-core-ui .tablenav input[type="tel"],
.wp-core-ui .tablenav input[type="time"],
.wp-core-ui .tablenav input[type="url"],
.wp-core-ui .tablenav input[type="week"],
.wp-core-ui .tablenav select {
	padding: 0 12px;
	/* inherits font size 14px */
	line-height: 2.14285714; /* 30px for 32px height with 14px font */
	min-height: 32px;
}

.wp-core-ui .tablenav select {
	float: right;
	margin-left: 6px;
	max-width: 12.5rem;
	padding: 0 8px 0 24px;
}

.wp-core-ui .tablenav .button {
	min-height: 32px;
	line-height: 2.30769231; /* 30px for 32px height with 13px font */
	padding: 0 12px;
}

#timezone_string option {
	margin-right: 1em;
}

.wp-core-ui .button.wp-hide-pw > .dashicons,
.wp-core-ui .button.wp-cancel-pw > .dashicons {
	width: 1.25rem;
	height: 1.25rem;
	font-size: 20px;
	line-height: 1;
	vertical-align: middle;
}

.button.wp-hide-pw.user-new-password-toggle {
	display: inline-flex;
	align-items: center;
	column-gap: 4px;
}

.wp-cancel-pw .dashicons-no {
	display: none;
}

label,
#your-profile label + a {
	vertical-align: middle;
}

fieldset label,
#your-profile label + a {
	vertical-align: middle;
}

.options-media-php [for*="_size_"] {
	min-width: 10em;
	vertical-align: baseline;
}

.options-media-php .small-text[name*="_size_"] {
	margin: 0 0 1em;
}

.wp-generate-pw {
	margin-top: 1em;
	position: relative;
}

.wp-pwd button {
	height: min-content;
}

.wp-pwd {
	margin-top: 1em;
	position: relative;
}

.mailserver-pass-wrap .wp-pwd {
	display: inline-block;
	margin-top: 0;
}

/* rtl:ignore */
#mailserver_pass {
	padding-right: 2.5rem;
}

/* rtl:ignore */
.mailserver-pass-wrap .button.wp-hide-pw {
	background: transparent;
	border: 1px solid transparent;
	box-shadow: none;
	font-size: 14px;
	line-height: 2;
	width: 2.5rem;
	min-width: 40px;
	margin: 0;
	padding: 0 9px;
	position: absolute;
	right: 0;
	top: 0;
}

.mailserver-pass-wrap .button.wp-hide-pw:hover {
	background: transparent;
	border-color: transparent;
}

.mailserver-pass-wrap .button.wp-hide-pw:focus {
	background: transparent;
	border-color: var(--wp-admin-theme-color);
	border-radius: 2px;
	box-shadow: 0 0 0 0.5px var(--wp-admin-theme-color);
	/* Only visible in Windows High Contrast mode */
	outline: 2px solid transparent;
}

.mailserver-pass-wrap .button.wp-hide-pw:active {
	background: transparent;
	box-shadow: none;
	transform: none;
}

#misc-publishing-actions label {
	vertical-align: baseline;
}

#pass-strength-result {
	background-color: #f0f0f0;
	border: 1px solid #cccccc;
	border-radius: 2px;
	color: #1e1e1e;
	margin: -1px 1px 5px;
	padding: 3px 5px;
	text-align: center;
	width: 25em;
	box-sizing: border-box;
	opacity: 0;
}

#pass-strength-result.short {
	background-color: #ffabaf;
	border-color: #e65054;
	opacity: 1;
}

#pass-strength-result.bad {
	background-color: #facfd2;
	border-color: #f86368;
	opacity: 1;
}

#pass-strength-result.good {
	background-color: #f5e6ab;
	border-color: #f0c33c;
	opacity: 1;
}

#pass-strength-result.strong {
	background-color: #b8e6bf;
	border-color: #68de7c;
	opacity: 1;
}

.password-input-wrapper {
	display: inline-block;
}

.password-input-wrapper input {
	font-family: Consolas, Monaco, monospace;
}

#pass1.short, #pass1-text.short {
	border-color: #e65054;
}

#pass1.bad, #pass1-text.bad {
	border-color: #f86368;
}

#pass1.good, #pass1-text.good {
	border-color: #f0c33c;
}

#pass1.strong, #pass1-text.strong {
	border-color: #68de7c;
}

#pass1:focus,
#pass1-text:focus {
	box-shadow: 0 0 0 0.5px var(--wp-admin-theme-color);
	/* Only visible in Windows High Contrast mode */
	outline: 2px solid transparent;
}

.pw-weak {
	display: none;
}

.indicator-hint {
	padding-top: 8px;
}

.wp-pwd [type="text"],
.wp-pwd [type="password"] {
	margin-bottom: 0;
	/* Same height as the buttons */
	min-height: 40px;
}

/* Hide the Edge "reveal password" native button */
.wp-pwd input::-ms-reveal {
	display: none;
}

#pass1-text,
.show-password #pass1 {
	display: none;
}

#pass1-text::-ms-clear {
	display: none;
}

.show-password #pass1-text {
	display: inline-block;
}

/* Caps lock warning */
.wp-pwd .caps-warning {
	display: none;
	position: relative;
	background: #fcf9e8;
	border: 1px solid #f0c33c;
	color: #1d2327;
	padding: 6px 10px;
	top: -8px;
}

.profile-php .wp-pwd .caps-warning {
	padding: 3px 5px;
	top: -4px;
	border-radius: 2px;
}

.wp-pwd .caps-icon {
	display: inline-flex;
	justify-content: center;
	width: 20px;
	height: 20px;
	margin-left: 5px;
	vertical-align: middle;
}

.wp-pwd .caps-warning-text {
	vertical-align: middle;
}
/* Caps lock warning */

p.search-box {
	display: flex;
	flex-wrap: wrap;
	align-items: center;
	column-gap: 0.5rem;
	position: relative;
	float: left;
	margin: 11px 0;
}

p.search-box input[type="search"],
p.search-box input[type="text"] {
	min-height: 32px;
	padding: 0 8px;
}

p.search-box .button {
	min-height: 32px;
	line-height: 2.30769231; /* 30px for 32px height with 13px font */
	padding: 0 12px;
}

.network-admin.themes-php p.search-box {
	clear: right;
}

.tablenav .search-plugins input[name="s"] {
	float: right;
	margin: 0 0 0 4px;
}

.tagsdiv .newtag {
	margin: 0;
}

.js.plugins-php .search-box .wp-filter-search {
	margin: 0;
	width: 280px;
}

input[type="text"].ui-autocomplete-loading,
input[type="email"].ui-autocomplete-loading {
	background-image: url(../images/loading.gif);
	background-repeat: no-repeat;
	background-position: left 5px center;
	visibility: visible;
}

input.ui-autocomplete-input.open {
	border-bottom-color: transparent;
}

ul#add-to-blog-users {
	margin: 0 14px 0 0;
}

.ui-autocomplete {
	padding: 0;
	margin: 0;
	list-style: none;
	position: absolute;
	z-index: 10000;
	border: 1px solid #4f94d4;
	box-shadow: 0 1px 2px rgba(79, 148, 212, 0.8);
	background-color: #fff;
}

.ui-autocomplete li {
	margin-bottom: 0;
	padding: 4px 10px;
	white-space: nowrap;
	text-align: right;
	cursor: pointer;
}

/* Colors for the wplink toolbar autocomplete. */
.ui-autocomplete .ui-state-focus {
	background-color: #dcdcde;
}

/* Colors for the tags autocomplete. */
.wp-tags-autocomplete .ui-state-focus,
.wp-tags-autocomplete [aria-selected="true"] {
	background-color: var(--wp-admin-theme-color);
	color: #fff;
	/* Only visible in Windows High Contrast mode */
	outline: 2px solid transparent;
}

/*------------------------------------------------------------------------------
  15.0 - Comments Screen
------------------------------------------------------------------------------*/

.form-table {
	border-collapse: collapse;
	margin-top: 0.5em;
	width: 100%;
	clear: both;
}

.form-table,
.form-table td,
.form-table th,
.form-table td p {
	font-size: 14px;
}

.form-table td {
	margin-bottom: 9px;
	padding: 15px 10px;
	line-height: 1.3;
	vertical-align: middle;
}

.form-table th,
.form-wrap label {
	color: #1d2327;
	font-weight: 400;
	text-shadow: none;
	vertical-align: baseline;
}

.form-table th {
	vertical-align: top;
	text-align: right;
	padding: 20px 0 20px 10px;
	width: 200px;
	line-height: 1.3;
	font-weight: 600;
}

.form-table th.th-full, /* Not used by core. Back-compat for pre-4.8 */
.form-table .td-full {
	width: auto;
	padding: 20px 0 20px 10px;
	font-weight: 400;
}

.form-table td p {
	margin-top: 4px;
	margin-bottom: 0;
}

.form-table .date-time-doc {
	margin-top: 1em;
}

.form-table p.timezone-info {
	margin: 1em 0;
	display: flex;
	flex-direction: column;
}

#local-time {
	margin-top: 0.5em;
}

.form-table td fieldset label {
	margin: 0.35em 0 0.5em !important;
	display: inline-block;
}

.form-table td fieldset p label {
	margin-top: 0 !important;
}

.form-table td fieldset label,
.form-table td fieldset p,
.form-table td fieldset li {
	line-height: 1.4;
}

.form-table .pre {
	padding: 8px;
	margin: 0;
}

table.form-table td .updated {
	font-size: 13px;
}

table.form-table td .updated p {
	font-size: 13px;
	margin: 0.3em 0;
}

/*------------------------------------------------------------------------------
  18.0 - Users
------------------------------------------------------------------------------*/

#profile-page .form-table textarea {
	width: 500px;
	margin-bottom: 6px;
}

#profile-page .form-table #rich_editing {
	margin-left: 5px
}

#your-profile legend {
	font-size: 22px;
}

#display_name {
	width: 15em;
}

#adduser .form-field input,
#createuser .form-field input {
	width: 25em;
}

.color-option {
	display: inline-block;
	width: 24%;
	padding: 5px 15px 15px;
	box-sizing: border-box;
	margin-bottom: 3px;
}

.color-option:hover,
.color-option.selected {
	background: #dcdcde;
}

.color-palette {
	display: table;
	width: 100%;
	border-spacing: 0;
	border-collapse: collapse;
}
.color-palette .color-palette-shade,
.color-palette td {
	display: table-cell;
	height: 20px;
	padding: 0;
	border: none;
}

.color-option {
	cursor: pointer;
}

.create-application-password .form-field {
	max-width: 25em;
}

.create-application-password label {
	font-weight: 600;
}

.create-application-password p.submit {
	margin-bottom: 0;
	padding-bottom: 0;
	display: block;
}

#application-passwords-section .notice {
	margin-top: 20px;
	margin-bottom: 0;
	word-wrap: break-word;
}

.application-password-display input.code {
	margin-bottom: 6px;
	width: 100%;
	max-width: 20em;
}

.auth-app-card.card {
	max-width: 768px;
}

.authorize-application-php .form-wrap p {
	display: block;
}

/*------------------------------------------------------------------------------
  19.0 - Tools
------------------------------------------------------------------------------*/

.tool-box .title {
	margin: 8px 0;
	font-size: 18px;
	font-weight: 400;
	line-height: 24px;
}

.label-responsive {
	vertical-align: middle;
}

#export-filters p {
	margin: 0 0 1em;
}

#export-filters p.submit {
	margin: 7px 0 5px;
}

/* Card styles */

.card {
	position: relative;
	margin-top: 20px;
	padding: 16px 24px;
	min-width: 255px;
	max-width: 520px;
	border: 1px solid rgb(0, 0, 0, 0.1);
	border-radius: 8px;
	background: #ffffff;
	box-sizing: border-box;
}

/* Press this styles */

.pressthis h4 {
	margin: 2em 0 1em;
}

.pressthis textarea {
	width: 100%;
	font-size: 1em;
}

#pressthis-code-wrap {
	overflow: auto;
}

.pressthis-bookmarklet-wrapper {
	margin: 20px 0 8px;
	vertical-align: top;
	position: relative;
	z-index: 1;
}

.pressthis-bookmarklet,
.pressthis-bookmarklet:hover,
.pressthis-bookmarklet:focus,
.pressthis-bookmarklet:active {
	display: inline-block;
	position: relative;
	cursor: move;
	color: #2c3338;
	background: #dcdcde;
	border-radius: 5px;
	border: 1px solid #c3c4c7;
	font-style: normal;
	line-height: 16px;
	font-size: 14px;
	text-decoration: none;
}

.pressthis-bookmarklet:active {
	outline: none;
}

.pressthis-bookmarklet:after {
	content: "";
	width: 70%;
	height: 55%;
	z-index: -1;
	position: absolute;
	left: 10px;
	bottom: 9px;
	background: transparent;
	transform: skew(-20deg) rotate(-6deg);
	box-shadow: 0 10px 8px rgba(0, 0, 0, 0.6);
}

.pressthis-bookmarklet:hover:after {
	transform: skew(-20deg) rotate(-9deg);
	box-shadow: 0 10px 8px rgba(0, 0, 0, 0.7);
}

.pressthis-bookmarklet span {
	display: inline-block;
	margin: 0;
	padding: 0 9px 8px 12px;
}

.pressthis-bookmarklet span:before {
	color: #787c82;
	font: normal 20px/1 dashicons;
	content: "\f157";
	content: "\f157" / '';
	position: relative;
	display: inline-block;
	top: 4px;
	margin-left: 4px;
}

.pressthis-js-toggle {
	margin-right: 10px;
	padding: 0;
	height: auto;
	vertical-align: top;
}

/* to override the button class being applied */
.pressthis-js-toggle.button.button {
	margin-right: 10px;
	padding: 0;
	height: auto;
	vertical-align: top;
}

.pressthis-js-toggle .dashicons {
	margin: 5px 7px 6px 8px;
	color: #50575e;
}

/*------------------------------------------------------------------------------
  20.0 - Settings
------------------------------------------------------------------------------*/

.timezone-info code {
	white-space: nowrap;
}

.defaultavatarpicker .avatar {
	margin: 2px 0;
	vertical-align: middle;
}

.options-general-php .date-time-text {
	display: inline-block;
	min-width: 10em;
}

.options-general-php input.small-text {
	width: 56px;
	margin: -2px 0;
	min-height: 32px;
}

.options-general-php .spinner {
	float: none;
	margin: -3px 3px 0;
}

.settings-php .language-install-spinner,
.options-general-php .language-install-spinner,
.user-edit-php .language-install-spinner,
.profile-php .language-install-spinner {
	display: inline-block;
	float: none;
	margin: -3px 5px 0;
	vertical-align: middle;
}

.form-table.permalink-structure .available-structure-tags {
	margin-top: 8px;
}

.form-table.permalink-structure .available-structure-tags ul {
	display: flex;
	flex-wrap: wrap;
	margin: 8px 0 0;
}

.form-table.permalink-structure .available-structure-tags li {
	margin: 6px 0 0 5px;
}

.form-table.permalink-structure .available-structure-tags li:last-child {
	margin-left: 0;
}

.form-table.permalink-structure .structure-selection .row {
	margin-bottom: 16px;
}

.form-table.permalink-structure .structure-selection .row > div {
	max-width: calc(100% - 24px);
	display: inline-flex;
	flex-direction: column;
}

.form-table.permalink-structure .structure-selection .row label {
	font-weight: 600;
}

.form-table.permalink-structure .structure-selection .row p {
	margin-top: 0;
}

.permalink-structure-optional-description code {
	display: inline-block;
}

/*------------------------------------------------------------------------------
  21.0 - Network Admin
------------------------------------------------------------------------------*/

.setup-php textarea {
	max-width: 100%;
}

.form-field #site-address {
	max-width: 25em;
}

.form-field #domain {
	max-width: 22em;
}

.form-field #site-title,
.form-field #admin-email,
.form-field #path,
.form-field #blog_registered,
.form-field #blog_last_updated {
	max-width: 25em;
}

.form-field #path {
	margin-bottom: 5px;
}

#search-users,
#search-sites {
	max-width: 60%;
}

.configuration-rules-label {
	font-weight: 600;
	margin-bottom: 4px;
}

/*------------------------------------------------------------------------------
   Credentials check dialog for Install and Updates
------------------------------------------------------------------------------*/

.request-filesystem-credentials-dialog {
	display: none;
	/* The customizer uses visibility: hidden on the body for full-overlays. */
	visibility: visible;
}

.request-filesystem-credentials-dialog .notification-dialog {
	top: 10%;
	max-height: 85%;
}

.request-filesystem-credentials-dialog-content {
	margin: 25px;
}

#request-filesystem-credentials-title {
	font-size: 1.3em;
	margin: 1em 0;
}

.request-filesystem-credentials-form legend {
	font-size: 1em;
	padding: 1.33em 0;
	font-weight: 600;
}

.request-filesystem-credentials-form input[type="text"],
.request-filesystem-credentials-form input[type="password"] {
	display: block;
}

.request-filesystem-credentials-dialog input[type="text"],
.request-filesystem-credentials-dialog input[type="password"] {
	width: 100%;
}

.request-filesystem-credentials-form .field-title {
	font-weight: 600;
}

.request-filesystem-credentials-dialog label[for="hostname"],
.request-filesystem-credentials-dialog label[for="public_key"],
.request-filesystem-credentials-dialog label[for="private_key"] {
	display: block;
	margin-bottom: 1em;
}

.request-filesystem-credentials-dialog .ftp-username,
.request-filesystem-credentials-dialog .ftp-password {
	float: right;
	width: 48%;
}

.request-filesystem-credentials-dialog .ftp-password {
	margin-right: 4%;
}

.request-filesystem-credentials-dialog .request-filesystem-credentials-action-buttons {
	text-align: left;
}

.request-filesystem-credentials-dialog label[for="ftp"] {
	margin-left: 10px;
}

.request-filesystem-credentials-dialog #auth-keys-desc {
	margin-bottom: 0;
}

#request-filesystem-credentials-dialog .button:not(:last-child) {
	margin-left: 10px;
}

#request-filesystem-credentials-form .cancel-button {
	display: none;
}

#request-filesystem-credentials-dialog .cancel-button {
	display: inline;
}

.request-filesystem-credentials-dialog .ftp-username,
.request-filesystem-credentials-dialog .ftp-password {
	float: none;
	width: auto;
}

.request-filesystem-credentials-dialog .ftp-username {
	margin-bottom: 1em;
}

.request-filesystem-credentials-dialog .ftp-password {
	margin: 0;
}

.request-filesystem-credentials-dialog .ftp-password em {
	color: #757575;
}

.request-filesystem-credentials-dialog label {
	display: block;
	line-height: 1.5;
	margin-bottom: 1em;
}

.request-filesystem-credentials-form legend {
	padding-bottom: 0;
}

.request-filesystem-credentials-form #ssh-keys legend {
	font-size: 1.3em;
}

.request-filesystem-credentials-form .notice {
	margin: 0 0 20px;
	clear: both;
}

/*------------------------------------------------------------------------------
   Privacy Policy settings screen
------------------------------------------------------------------------------*/
.tools-privacy-policy-page form {
	margin-bottom: 1.3em;
}

.tools-privacy-policy-page input.button {
	margin: 0 6px 0 1px;
}

.tools-privacy-policy-page select {
	margin: 0 6px 0.5em 1px;
}

.tools-privacy-edit {
	margin: 1.5em 0;
}

.tools-privacy-policy-page span {
	line-height: 2;
}

.privacy_requests .column-email {
	width: 40%;
}

.privacy_requests .column-type {
	text-align: center;
}

.privacy_requests thead td:first-child,
.privacy_requests tfoot td:first-child {
	border-right: 4px solid #fff;
}

.privacy_requests tbody th {
	border-right: 4px solid #fff;
	background: #fff;
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}

.privacy_requests .row-actions {
	color: #787c82;
}

.privacy_requests .row-actions.processing {
	position: static;
}

.privacy_requests tbody .has-request-results th {
	box-shadow: none;
}

.privacy_requests tbody .request-results th .notice {
	margin: 0 0 5px;
}

.privacy_requests tbody td {
	background: #fff;
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}

.privacy_requests tbody .has-request-results td {
	box-shadow: none;
}

.privacy_requests .next_steps .button {
	word-wrap: break-word;
	white-space: normal;
}

.privacy_requests .status-request-confirmed th,
.privacy_requests .status-request-confirmed td {
	background-color: #fff;
	border-right-color: #72aee6;
}

.privacy_requests .status-request-failed th,
.privacy_requests .status-request-failed td {
	background-color: #f6f7f7;
	border-right-color: #d63638;
}

.privacy_requests .export_personal_data_failed a {
	vertical-align: baseline;
}

.status-label {
	font-weight: 600;
}

.status-label.status-request-pending {
	font-weight: 400;
	font-style: italic;
	color: #646970;
}

.status-label.status-request-failed {
	color: #d63638;
	font-weight: 600;
}

.privacy_requests .status-date {
	display: block;
	font-weight: 400;
}

.wp-privacy-request-form {
	clear: both;
}

.wp-privacy-request-form-field {
	margin: 1.5em 0;
}

.wp-privacy-request-form input {
	margin: 0;
}

/* =Media Queries
-------------------------------------------------------------- */

@media screen and (max-width: 782px) {
	/* Input Elements */
	textarea {
		-webkit-appearance: none;
	}

	input[type="text"],
	input[type="password"],
	input[type="date"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="email"],
	input[type="month"],
	input[type="number"],
	input[type="search"],
	input[type="tel"],
	input[type="time"],
	input[type="url"],
	input[type="week"] {
		-webkit-appearance: none;
		padding: 0 12px;
		min-height: 40px;
	}

	::-webkit-datetime-edit {
		line-height: 1.875; /* 30px */
	}

	input[type="checkbox"],
	.widefat th input[type="checkbox"],
	.widefat thead td input[type="checkbox"],
	.widefat tfoot td input[type="checkbox"] {
		-webkit-appearance: none;
	}

	.widefat th input[type="checkbox"],
	.widefat thead td input[type="checkbox"],
	.widefat tfoot td input[type="checkbox"] {
		margin-bottom: 8px;
	}

	input[type="checkbox"]:checked:before,
	.widefat th input[type="checkbox"]:before,
	.widefat thead td input[type="checkbox"]:before,
	.widefat tfoot td input[type="checkbox"]:before {
		width: 1.875rem;
		height: 1.875rem;
		margin: -0.1875rem -0.3125rem;
	}

	input[type="radio"],
	input[type="checkbox"] {
		height: 1.5625rem;
		width: 1.5625rem;
	}

	.wp-admin p input[type="checkbox"],
	.wp-admin p input[type="radio"] {
		margin-top: -0.1875rem;
	}

	input[type="radio"]:checked:before {
		vertical-align: middle;
		width: 0.5625rem;
		height: 0.5625rem;
		margin: 0.4375rem;
		line-height: 0.76190476;
	}

	.wp-core-ui select,
	.wp-admin .form-table select {
		min-height: 40px;
		font-size: 16px;
		line-height: 2.5; /* 40px for 16px font */
		padding: 0 12px 0 24px;
	}

	.wp-admin .button-cancel {
		margin-bottom: 0;
		padding: 2px 0;
		font-size: 14px;
		vertical-align: middle;
	}

	#adduser .form-field input,
	#createuser .form-field input {
		width: 100%;
	}

	.form-table {
		box-sizing: border-box;
	}

	.form-table th,
	.form-table td,
	.label-responsive {
		display: block;
		width: auto;
		vertical-align: middle;
	}

	.label-responsive {
		margin: 0.5em 0;
	}

	.export-filters li {
		margin-bottom: 0;
	}

	.form-table .color-palette .color-palette-shade,
	.form-table .color-palette td {
		display: table-cell;
		width: 15px;
		height: 30px;
		padding: 0;
	}

	.form-table .color-palette {
		margin-left: 10px;
	}

	textarea,
	input {
		font-size: 16px;
	}

	.form-table td input[type="text"],
	.form-table td input[type="email"],
	.form-table td input[type="password"],
	.form-table td select,
	.form-table td textarea,
	.form-table span.description,
	#profile-page .form-table textarea {
		width: 100%;
		display: block;
		max-width: none;
		box-sizing: border-box;
	}

	.form-table .form-required.form-invalid td:after {
		float: left;
		margin: -30px 0 0 3px;
	}

	input[type="text"].small-text,
	input[type="search"].small-text,
	input[type="password"].small-text,
	input[type="number"].small-text,
	input[type="number"].small-text,
	.form-table input[type="text"].small-text {
		width: auto;
		max-width: 4.375em; /* 70px, enough for 4 digits to fit comfortably */
		display: inline;
		padding: 3px 6px;
		margin: 0 3px;
	}

	.form-table .regular-text ~ input[type="text"].small-text {
		margin-top: 5px;
	}

	#pass-strength-result {
		width: 100%;
		box-sizing: border-box;
		padding: 8px;
	}

	.profile-php .wp-pwd .caps-warning {
		padding: 8px;
	}

	.password-input-wrapper {
		display: block;
	}

	p.search-box {
		float: none;
		width: 100%;
		margin-bottom: 20px;
		display: flex;
	}

	p.search-box input[name="s"] {
		width: 100%;
		float: none;
		margin-bottom: 10px;
		vertical-align: middle;
	}
	.js.plugins-php .search-box .wp-filter-search {
		width: 100%;
		margin-bottom: 0;
	}

	p.search-box input[type="submit"] {
		margin-bottom: 10px;
	}

	.form-table span.description {
		display: inline;
		padding: 4px 0 0;
		line-height: 1.4;
		font-size: 14px;
	}

	.form-table th {
		padding: 10px 0 0;
		border-bottom: 0;
	}

	.form-table td {
		margin-bottom: 0;
		padding: 4px 0 6px;
	}

	.form-table.permalink-structure td code {
		display: inline-block;
	}

	.form-table.permalink-structure .structure-selection {
		margin-top: 8px;
	}

	.form-table.permalink-structure .structure-selection .row > div {
		max-width: calc(100% - 36px);
		width: 100%;
	}

	.form-table.permalink-structure td input[type="text"] {
		margin-top: 4px;
	}

	.permalink-structure-has-blog-prefix {
		display: flex;
		align-items: center;
	}

	.form-table input.regular-text {
		width: 100%;
	}

	.form-table label {
		font-size: 14px;
	}

	.form-table td > label:first-child {
		display: inline-block;
		margin-top: 0.35em;
	}

	.background-position-control .button-group > label {
		font-size: 0;
	}

	.form-table fieldset label {
		display: block;
	}

	.form-field #domain {
		max-width: none;
	}

	/* New Password */
	.wp-pwd {
		position: relative;
	}

	/* Needs higher specificity than normal input type text and password. */
	#profile-page .form-table #pass1 {
		padding-left: 90px;
	}

	.wp-pwd button.button {
		background: transparent;
		border: 1px solid transparent;
		box-shadow: none;
		line-height: 2;
		margin: 0;
		padding: 5px 9px;
		position: absolute;
		left: 0;
		top: 0;
		width: 2.375rem;
		height: 2.375rem;
		min-width: 40px;
		min-height: 40px;
	}

	.wp-pwd button.wp-hide-pw {
		left: 2.5rem;
	}

	body.user-new-php .wp-pwd button.wp-hide-pw {
		left: 0;
	}

	.wp-pwd button.button:hover,
	.wp-pwd button.button:focus {
		background: transparent;
	}

	.wp-pwd button.button:active {
		background: transparent;
		box-shadow: none;
		transform: none;
	}

	.wp-pwd .button .text {
		display: none;
	}

	.wp-pwd [type="text"],
	.wp-pwd [type="password"] {
		line-height: 2;
		padding-left: 5rem;
	}

	body.user-new-php .wp-pwd [type="text"],
	body.user-new-php .wp-pwd [type="password"] {
		padding-left: 2.5rem;
	}

	.wp-cancel-pw .dashicons-no {
		display: inline-block;
	}

	.mailserver-pass-wrap .wp-pwd {
		display: block;
	}

	/* rtl:ignore */
	#mailserver_pass {
		padding-left: 10px;
	}

	.options-general-php input[type="text"].small-text {
		max-width: 6.25em;
		margin: 0;
	}

	/* Privacy Policy settings screen */
	.tools-privacy-policy-page form.wp-create-privacy-page {
		margin-bottom: 1em;
	}

	.tools-privacy-policy-page input#set-page,
	.tools-privacy-policy-page select {
		margin: 10px 0 0;
	}

	.tools-privacy-policy-page .wp-create-privacy-page span {
		display: block;
		margin-bottom: 1em;
	}

	.tools-privacy-policy-page .wp-create-privacy-page .button {
		margin-right: 0;
	}

	.wp-list-table.privacy_requests tr:not(.inline-edit-row):not(.no-items) td.column-primary:not(.check-column) {
		display: table-cell;
	}

	.wp-list-table.privacy_requests.widefat th input,
	.wp-list-table.privacy_requests.widefat thead td input {
		margin-right: 5px;
	}

	.wp-privacy-request-form-field input[type="text"] {
		width: 100%;
		margin-bottom: 10px;
		vertical-align: middle;
	}

	.regular-text {
		max-width: 100%;
	}
}

@media only screen and (max-width: 768px) {
	.form-field input[type="text"],
	.form-field input[type="email"],
	.form-field input[type="password"],
	.form-field select,
	.form-field textarea {
		width: 99%;
	}

	.form-wrap .form-field {
		padding: 0;
	}
}

@media only screen and (max-height: 480px), screen and (max-width: 450px) {
	/* Request Credentials / File Editor Warning */
	.request-filesystem-credentials-dialog .notification-dialog,
	.file-editor-warning .notification-dialog {
		width: 100%;
		height: 100%;
		max-height: 100%;
		position: fixed;
		top: 0;
		margin: 0;
		right: 0;
	}
}

/* Smartphone */
@media screen and (max-width: 600px) {
	/* Color Picker Options */
	.color-option {
		width: 49%;
	}
}

@media only screen and (max-width: 320px) {
	.options-general-php .date-time-text.date-time-custom-text {
		min-width: 0;
		margin-left: 0.5em;
	}
}

@keyframes rotation {
	0% {
		transform: rotate(0deg);
	}
	100% {
		transform: rotate(-359deg);
	}
}
